;; Generated package description from switchy-window.el  -*- no-byte-compile: t -*-
(define-package "switchy-window" "1.0.0.20230410.73719" "A most-recently-used window switcher" '((emacs "25.1") (compat "29.1.4.1")) :commit "92b2479cb8f86bea5f3147c4f429efbbc11ec3d1" :authors '(("Tassilo Horn" . "tsdh@gnu.org")) :maintainer '("Tassilo Horn" . "tsdh@gnu.org") :keywords '("windows") :url "https://sr.ht/~tsdh/switchy-window/")
